@@ -36,54 +36,65 @@ Global variables and functions for program
     centreWindowOnWindow( self, parentWindow, width=400, height=250 )
     errorBeep()
 """
-
 from gettext import gettext as _
-
-LAST_MODIFIED_DATE = '2020-04-11' # by RJH
-SHORT_PROGRAM_NAME = "BiblelatorGlobals"
-PROGRAM_NAME = "Biblelator Globals"
-PROGRAM_VERSION = '0.46'
-programNameVersion = f'{PROGRAM_NAME} v{PROGRAM_VERSION}'
-
-debuggingThisModule = False
-
-
 import os
 from pathlib import Path
 import re
 
 # BibleOrgSys imports
 from BibleOrgSys import BibleOrgSysGlobals
-from BibleOrgSys.BibleOrgSysGlobals import vPrint
+from BibleOrgSys.BibleOrgSysGlobals import fnPrint, vPrint, dPrint
 
 
+LAST_MODIFIED_DATE = '2020-05-10' # by RJH
+SHORT_PROGRAM_NAME = "BiblelatorGlobals"
+PROGRAM_NAME = "Biblelator Globals"
+PROGRAM_VERSION = '0.46' # This is the version number that will be displayed inside the app
+programNameVersion = f'{PROGRAM_NAME} v{PROGRAM_VERSION}'
+
+debuggingThisModule = False
 
 
-# Programmed settings
+# Programme settings
 APP_NAME = 'Biblelator' # Ugly coz doesn't necessarily match the PROGRAM_NAME in Biblelator.py
-APP_NAME_VERSION = '{} v{}'.format( APP_NAME, PROGRAM_VERSION ) # Ugly coz doesn't necessarily match the PROGRAM_VERSION in Biblelator.py
-DATA_FOLDER_NAME = APP_NAME + 'Data/'
-LOGGING_SUBFOLDER_NAME = APP_NAME + 'Logs/'
-SETTINGS_SUBFOLDER_NAME = APP_NAME + 'Settings/'
-PROJECTS_SUBFOLDER_NAME = APP_NAME + 'Projects/'
+APP_NAME_VERSION = f'{APP_NAME} v{PROGRAM_VERSION}' # Ugly coz doesn't necessarily match the PROGRAM_VERSION in Biblelator.py
+DATA_SUBFOLDER_NAME = f'{APP_NAME}Data/'
+LOGGING_SUBFOLDER_NAME = f'{APP_NAME}Logs/'
+SETTINGS_SUBFOLDER_NAME = f'{APP_NAME}Settings/'
+PROJECTS_SUBFOLDER_NAME = f'{APP_NAME}Projects/'
 
 
 ##########################################################################################################
 #
-# Readable folder paths (Writeable ones are further down)
+# Most of this file is "constants" and useful functions.
+#
+# This section has actual global variables.
+#
+theApp = None # This will contain a pointer to the main Application class
+              #     so we don't have to keep passing it thru all the levels.
+
+def setApp( mainApp ):
+    global theApp
+    assert mainApp
+    theApp = mainApp
+
+
+##########################################################################################################
+#
+# Readable folder paths
 SOURCE_BASE_FOLDERPATH = Path( __file__ ).parent.resolve() # Folder containing this file
-#vPrint( 'Quiet', debuggingThisModule, f"SOURCE_BASE_FOLDERPATH = {SOURCE_BASE_FOLDERPATH}" )
+#dPrint( 'Quiet', debuggingThisModule, f"SOURCE_BASE_FOLDERPATH = {SOURCE_BASE_FOLDERPATH}" )
 DATAFILES_FOLDERPATH = SOURCE_BASE_FOLDERPATH.joinpath( 'DataFiles/' )
 # DERIVED_DATAFILES_FOLDERPATH = DATAFILES_FOLDERPATH.joinpath( 'DerivedFiles/' )
 
 # LIBRARY_BASE_FOLDERPATH = SOURCE_BASE_FOLDERPATH.parent # Folder above the one containing this file
-# #vPrint( 'Quiet', debuggingThisModule, f"LIBRARY_BASE_FOLDERPATH = {LIBRARY_BASE_FOLDERPATH}" )
+# #dPrint( 'Quiet', debuggingThisModule, f"LIBRARY_BASE_FOLDERPATH = {LIBRARY_BASE_FOLDERPATH}" )
 # TESTS_FOLDERPATH = LIBRARY_BASE_FOLDERPATH.joinpath( 'Tests/' )
 # TEST_DATA_FOLDERPATH = TESTS_FOLDERPATH.joinpath( 'DataFilesForTests/' )
 
 # # Resources like original language lexicons should be based from this folder
 # BADBAD_PARALLEL_RESOURCES_BASE_FOLDERPATH = LIBRARY_BASE_FOLDERPATH.parent # Two folders above the one containing this file
-# vPrint( 'Quiet', debuggingThisModule, f"BADBAD_PARALLEL_RESOURCES_BASE_FOLDERPATH = {BADBAD_PARALLEL_RESOURCES_BASE_FOLDERPATH}" )
+# dPrint( 'Quiet', debuggingThisModule, f"BADBAD_PARALLEL_RESOURCES_BASE_FOLDERPATH = {BADBAD_PARALLEL_RESOURCES_BASE_FOLDERPATH}" )
 
 
 # Constants for tkinter
@@ -144,7 +155,7 @@ DEFAULT_KEY_BINDING_DICT = {
     _('About'):('F12','<F12>'),
     _('Close'):('Ctrl+F4','<Control-F4>'),
     _('Quit'):('Alt+F4','<Alt-F4>'), }
-#vPrint( 'Quiet', debuggingThisModule, DEFAULT_KEY_BINDING_DICT ); halt
+#dPrint( 'Quiet', debuggingThisModule, DEFAULT_KEY_BINDING_DICT ); halt
 
 
 
@@ -207,7 +218,7 @@ def centreWindow( self, width=400, height=250 ):
 
     x = (screenWidth - width) // 2
     y = (screenHeight - height) // 2
-    #vPrint( 'Quiet', debuggingThisModule, "centreWindow", width, height, screenWidth, screenHeight, x, y )
+    #dPrint( 'Quiet', debuggingThisModule, "centreWindow", width, height, screenWidth, screenHeight, x, y )
 
     self.geometry('{}x{}+{}+{}'.format( width, height, x, y ) )
 # end of BiblelatorGlobals.centreWindow
@@ -217,11 +228,11 @@ def centreWindowOnWindow( self, parentWindow, width=400, height=250 ):
     """
     """
     parentWidth, parentHeight, parentXOffset, parentYOffset = parseWindowGeometry( parentWindow.winfo_geometry() )
-    #vPrint( 'Quiet', debuggingThisModule, "centreWindowOnWindow parent is", "w =",parentWidth, "h =",parentHeight, "x =",parentXOffset, "y =",parentYOffset )
+    #dPrint( 'Quiet', debuggingThisModule, "centreWindowOnWindow parent is", "w =",parentWidth, "h =",parentHeight, "x =",parentXOffset, "y =",parentYOffset )
 
     x = parentXOffset + (parentWidth - width) // 2
     y = parentYOffset + (parentHeight - height) // 2
-    #vPrint( 'Quiet', debuggingThisModule, "centreWindowOnWindow", "w =",width, "h =",height, "x =",x, "y =",y )
+    #dPrint( 'Quiet', debuggingThisModule, "centreWindowOnWindow", "w =",width, "h =",height, "x =",x, "y =",y )
 
     self.geometry('{}x{}+{}+{}'.format( width, height, x, y ) )
 # end of BiblelatorGlobals.centreWindowOnWindow
@@ -250,7 +261,7 @@ def briefDemo() -> None:
     from tkinter import Tk
 
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
-    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
+    dPrint( 'Quiet', debuggingThisModule, "Running demo…" )
 
     vPrint( 'Quiet', debuggingThisModule, "assembleWindowGeometry( 123, 234, 345, 456 ) = {}".format( assembleWindowGeometry( 123, 234, 345, 456 ) ) )
     g1, g2 = "493x152+820+491", "493x123+-119+9"
@@ -262,7 +273,7 @@ def briefDemo() -> None:
 
     #tkRootWindow = Tk()
     #tkRootWindow.title( programNameVersion )
-    #settings = ApplicationSettings( DATA_FOLDER_NAME, SETTINGS_SUBFOLDER_NAME, PROGRAM_NAME )
+    #settings = ApplicationSettings( DATA_SUBFOLDER_NAME, SETTINGS_SUBFOLDER_NAME, PROGRAM_NAME )
     #settings.load()
 
     #application = Application( parent=tkRootWindow, settings=settings )
@@ -272,15 +283,38 @@ def briefDemo() -> None:
 
     # Start the program running
     #tkRootWindow.mainloop()
-# end of BiblelatorGlobals.demo
-
+# end of BiblelatorGlobals.briefDemo
 
 def fullDemo() -> None:
     """
     Full demo to check class is working
     """
-    briefDemo()
-# end of fullDemo
+    from tkinter import Tk
+
+    BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
+    dPrint( 'Quiet', debuggingThisModule, "Running demo…" )
+
+    vPrint( 'Quiet', debuggingThisModule, "assembleWindowGeometry( 123, 234, 345, 456 ) = {}".format( assembleWindowGeometry( 123, 234, 345, 456 ) ) )
+    g1, g2 = "493x152+820+491", "493x123+-119+9"
+    p1, p2 = parseWindowGeometry( g1 ), parseWindowGeometry( g2 )
+    vPrint( 'Quiet', debuggingThisModule, "parseWindowGeometry( {} ) = {}".format( g1, p1 ) )
+    vPrint( 'Quiet', debuggingThisModule, "assembleWindowGeometryFromList( {} ) = {}".format( p1, assembleWindowGeometryFromList( p1 ) ) )
+    vPrint( 'Quiet', debuggingThisModule, "parseWindowGeometry( {} ) = {}".format( g2, p2 ) )
+    vPrint( 'Quiet', debuggingThisModule, "assembleWindowGeometryFromList( {} ) = {}".format( p2, assembleWindowGeometryFromList( p2 ) ) )
+
+    #tkRootWindow = Tk()
+    #tkRootWindow.title( programNameVersion )
+    #settings = ApplicationSettings( DATA_SUBFOLDER_NAME, SETTINGS_SUBFOLDER_NAME, PROGRAM_NAME )
+    #settings.load()
+
+    #application = Application( parent=tkRootWindow, settings=settings )
+    # Calls to the window manager class (wm in Tk)
+    #application.master.title( programNameVersion )
+    #application.master.minsize( application.minimumXSize, application.minimumYSize )
+
+    # Start the program running
+    #tkRootWindow.mainloop()
+# end of BiblelatorGlobals.fullDemo
 
 if __name__ == '__main__':
     from multiprocessing import freeze_support
