@@ -5,7 +5,7 @@
 #
 # Functions to support the autocomplete function in text editors
 #
-# Copyright (C) 2016-2018 Robert Hunt
+# Copyright (C) 2016-2020 Robert Hunt
 # Author: Robert Hunt <Freely.Given.org+Biblelator@gmail.com>
 # License: See gpl-3.0.txt
 #
@@ -30,18 +30,7 @@ Autocomplete is the ability to pop-up a little window of suggested word completi
 This module contains most of the helper functions for loading the autocomplete
     words (which may be from a Bible or from a dictionary, etc.)
 """
-
 from gettext import gettext as _
-
-LAST_MODIFIED_DATE = '2018-11-25' # by RJH
-SHORT_PROGRAM_NAME = "AutocompleteFunctions"
-PROGRAM_NAME = "Biblelator Autocomplete Functions"
-PROGRAM_VERSION = '0.46'
-programNameVersion = f'{PROGRAM_NAME} v{PROGRAM_VERSION}'
-
-debuggingThisModule = False
-
-
 import sys
 import os
 import logging
@@ -53,7 +42,6 @@ import tkinter as tk
 
 # Biblelator imports
 if __name__ == '__main__':
-    import sys
     aboveAboveFolderpath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
     if aboveAboveFolderpath not in sys.path:
         sys.path.insert( 0, aboveAboveFolderpath )
@@ -61,11 +49,19 @@ from Biblelator.Windows.TextBoxes import TRAILING_SPACE_SUBSTITUTE, MULTIPLE_SPA
 
 # BibleOrgSys imports
 from BibleOrgSys import BibleOrgSysGlobals
-from BibleOrgSys.BibleOrgSysGlobals import vPrint
+from BibleOrgSys.BibleOrgSysGlobals import fnPrint, vPrint, dPrint
 #from BibleOrgSys.Internals.InternalBibleInternals import BOS_PRINTABLE_MARKERS, BOS_EXTRA_TYPES
 from BibleOrgSys.Reference.USFM3Markers import USFM_PRINTABLE_MARKERS
 
 
+LAST_MODIFIED_DATE = '2020-04-30' # by RJH
+SHORT_PROGRAM_NAME = "AutocompleteFunctions"
+PROGRAM_NAME = "Biblelator Autocomplete Functions"
+PROGRAM_VERSION = '0.46'
+programNameVersion = f'{PROGRAM_NAME} v{PROGRAM_VERSION}'
+
+debuggingThisModule = False
+
 
 AVOID_BOOKS = ( 'FRT', 'BAK', 'GLS', 'XXA','XXB','XXC','XXD','XXE','XXF','XXG', 'NDX', 'UNK', )
 END_CHARS_TO_REMOVE = ',—.–!?”:;' # NOTE: This intentionally doesn't include close parenthesis and similar
@@ -83,11 +79,11 @@ def setAutocompleteWords( editWindowObject, wordList, append=False ):
     """
     logging.info( "AutocompleteFunctions.setAutocompleteWords( …, {}, {} )".format( len(wordList), append ) )
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        #vPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.setAutocompleteWords( {} )".format( wordList, append ) )
+        #dPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.setAutocompleteWords( {} )".format( wordList, append ) )
         vPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.setAutocompleteWords( …, {}, {} )".format( len(wordList), append ) )
-        editWindowObject.parentApp.setDebugText( "setAutocompleteWords…" )
+        BiblelatorGlobals.theApp.setDebugText( "setAutocompleteWords…" )
 
-    editWindowObject.parentApp.setWaitStatus( _("Setting autocomplete words…") )
+    BiblelatorGlobals.theApp.setWaitStatus( _("Setting autocomplete words…") )
     if not append: editWindowObject.autocompleteWords = {}
 
     for word in wordList:
@@ -110,10 +106,10 @@ def setAutocompleteWords( editWindowObject, wordList, append=False ):
                             if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
                                 vPrint( 'Quiet', debuggingThisModule, "    setAutocompleteWords added {!r} as new wordChar".format( char ) )
         #elif BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            #vPrint( 'Quiet', debuggingThisModule, "    setAutocompleteWords discarded {!r} as too short".format( word ) )
+            #dPrint( 'Quiet', debuggingThisModule, "    setAutocompleteWords discarded {!r} as too short".format( word ) )
         #elif BibleOrgSysGlobals.debugFlag and debuggingThisModule:
             #if "'" not in word:
-                #vPrint( 'Quiet', debuggingThisModule, "    setAutocompleteWords discarded {!r} as unwanted".format( word ) )
+                #dPrint( 'Quiet', debuggingThisModule, "    setAutocompleteWords discarded {!r} as unwanted".format( word ) )
 
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule: # write wordlist
         vPrint( 'Quiet', debuggingThisModule, "  setAutocompleteWords: Writing autocomplete words to file…" )
@@ -146,7 +142,7 @@ def setAutocompleteWords( editWindowObject, wordList, append=False ):
             for spaceCount in wordNumTotals:
                 vPrint( 'Quiet', debuggingThisModule, "    {} words: {}".format( spaceCount+1, wordNumTotals[spaceCount] ) )
 
-    editWindowObject.parentApp.setReadyStatus()
+    BiblelatorGlobals.theApp.setReadyStatus()
 # end of AutocompleteFunctions.setAutocompleteWords
 
 
@@ -170,7 +166,7 @@ def countBookWords( BBB, internalBible, filename, isCurrentBook, internalMarkers
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
         vPrint( 'Quiet', debuggingThisModule, "countBookWords( {}, {}, {} )".format( BBB, internalBible, filename ) )
     if BBB in AVOID_BOOKS:
-        #vPrint( 'Quiet', debuggingThisModule, "Didn't load autocomplete words from {} {}".format( internalBible.getAName(), BBB ) )
+        #dPrint( 'Quiet', debuggingThisModule, "Didn't load autocomplete words from {} {}".format( internalBible.getAName(), BBB ) )
         return # Sometimes these books contain words from other languages, etc.
 
     countIncrement = 3 if isCurrentBook else 1 # Each word in current book counts higher so appears higher in the list
@@ -186,14 +182,14 @@ def countBookWords( BBB, internalBible, filename, isCurrentBook, internalMarkers
         """
         Note: Punctuation etc. is NOT removed.
         """
-        #vPrint( 'Quiet', debuggingThisModule, "countWords( {!r} )".format( textLine ) )
+        #dPrint( 'Quiet', debuggingThisModule, "countWords( {!r} )".format( textLine ) )
         if '\\' in textLine: # we have internal markers to remove
-            #vPrint( 'Quiet', debuggingThisModule, "  INT", marker, textLine )
+            #dPrint( 'Quiet', debuggingThisModule, "  INT", marker, textLine )
             for iMarker in internalMarkers:
-                #vPrint( 'Quiet', debuggingThisModule, "   GOT", repr(iMarker) )
+                #dPrint( 'Quiet', debuggingThisModule, "   GOT", repr(iMarker) )
                 textLine = textLine.replace( iMarker+' ',' ' ).replace( iMarker+'*',' ' )
                 if not '\\' in textLine: break
-            #vPrint( 'Quiet', debuggingThisModule, "  NOW", marker, textLine )
+            #dPrint( 'Quiet', debuggingThisModule, "  NOW", marker, textLine )
         words = textLine.replace('—','— ').replace('–','– ').split() # Treat em-dash and en-dash as word break characters
 
         # Now look for (and count) single and some multiple word sequences
@@ -208,25 +204,25 @@ def countBookWords( BBB, internalBible, filename, isCurrentBook, internalMarkers
             #if word[-1] not in '—.–':
             if wx < len(words)-1: # it's not the last word in the line
                 doubleWord = word+' '+words[wx+1]
-                #vPrint( 'Quiet', debuggingThisModule, 'doubleWord', repr(doubleWord) )
+                #dPrint( 'Quiet', debuggingThisModule, 'doubleWord', repr(doubleWord) )
                 adjustedDoubleWord = doubleWord[:-1] if doubleWord[-1] in END_CHARS_TO_REMOVE else doubleWord
                 if '. ' not in adjustedDoubleWord: # don't go across sentence boundaries
                     wordCounts[adjustedDoubleWord] += countIncrement
                 if wx < len(words)-2: # there's still two words after this one
                     tripleWord = doubleWord+' '+words[wx+2]
-                    #vPrint( 'Quiet', debuggingThisModule, 'tripleWord', repr(tripleWord) )
+                    #dPrint( 'Quiet', debuggingThisModule, 'tripleWord', repr(tripleWord) )
                     adjustedTripleWord = tripleWord[:-1] if tripleWord[-1] in END_CHARS_TO_REMOVE else tripleWord
                     if '. ' not in adjustedTripleWord: # don't go across sentence boundaries
                         wordCounts[adjustedTripleWord] += countIncrement
                     if wx < len(words)-3: # there's still three words after this one
                         quadWord = tripleWord+' '+words[wx+3]
-                        #vPrint( 'Quiet', debuggingThisModule, 'quadWord', repr(quadWord) )
+                        #dPrint( 'Quiet', debuggingThisModule, 'quadWord', repr(quadWord) )
                         adjustedQuadWord = quadWord[:-1] if quadWord[-1] in END_CHARS_TO_REMOVE else quadWord
                         if '. ' not in adjustedQuadWord: # don't go across sentence boundaries
                             wordCounts[adjustedQuadWord] += countIncrement
                         if wx < len(words)-4: # there's still four words after this one
                             quinWord = quadWord+' '+words[wx+4]
-                            #vPrint( 'Quiet', debuggingThisModule, 'quinWord', repr(quinWord) )
+                            #dPrint( 'Quiet', debuggingThisModule, 'quinWord', repr(quinWord) )
                             adjustedQuinWord = quinWord[:-1] if quinWord[-1] in END_CHARS_TO_REMOVE else quinWord
                             if '. ' not in adjustedQuinWord: # don't go across sentence boundaries
                                 wordCounts[adjustedQuinWord] += countIncrement
@@ -244,22 +240,22 @@ def countBookWords( BBB, internalBible, filename, isCurrentBook, internalMarkers
                 if line and line[-1]=='\n': line=line[:-1] # Removing trailing newline character
                 if not line: continue # Just discard blank lines
                 lastLine = line
-                #vPrint( 'Quiet', debuggingThisModule, 'USFM file line is {!r}'.format( line ) )
+                #dPrint( 'Quiet', debuggingThisModule, 'USFM file line is {!r}'.format( line ) )
                 #if line[0:2]=='\\_': continue # Just discard Toolbox header lines
                 if line[0]=='#': continue # Just discard comment lines
 
                 if line[0]!='\\': # Not a SFM line
                     if lastMarker is None: # We don't have any SFM data lines yet
                         logging.error( "countBookWords: Non-USFM line in {} -- line ignored at #{}".format( USFMFilepath, lineCount) )
-                        #vPrint( 'Quiet', debuggingThisModule, "SFMFile.py: XXZXResult is", lineDuples, len(line) )
+                        #dPrint( 'Quiet', debuggingThisModule, "SFMFile.py: XXZXResult is", lineDuples, len(line) )
                         #for x in range(0, min(6,len(line))):
-                            #vPrint( 'Quiet', debuggingThisModule, x, "'" + str(ord(line[x])) + "'" )
+                            #dPrint( 'Quiet', debuggingThisModule, x, "'" + str(ord(line[x])) + "'" )
                         #raise IOError('Oops: Line break on last line ??? not handled here "' + line + '"')
                     else: # Append this continuation line
                         if lastMarker in USFM_PRINTABLE_MARKERS:
                             #oldmarker, oldtext = lineDuples.pop()
-                            #vPrint( 'Quiet', debuggingThisModule, "Popped",oldmarker,oldtext)
-                            #vPrint( 'Quiet', debuggingThisModule, "Adding", line, "to", oldmarker, oldtext)
+                            #dPrint( 'Quiet', debuggingThisModule, "Popped",oldmarker,oldtext)
+                            #dPrint( 'Quiet', debuggingThisModule, "Adding", line, "to", oldmarker, oldtext)
                             #lineDuples.append( (oldmarker, oldtext+' '+line) )
                             countWords( line )
                         continue
@@ -287,14 +283,14 @@ def countBookWords( BBB, internalBible, filename, isCurrentBook, internalMarkers
                     marker = lineAfterBackslash
                     text = ''
 
-                #vPrint( 'Quiet', debuggingThisModule, " ", repr(marker), repr(text) )
+                #dPrint( 'Quiet', debuggingThisModule, " ", repr(marker), repr(text) )
                 #if marker not in ignoreSFMs:
                 if marker in USFM_PRINTABLE_MARKERS and text:
-                    #vPrint( 'Quiet', debuggingThisModule, "   1", marker, text )
+                    #dPrint( 'Quiet', debuggingThisModule, "   1", marker, text )
                     if marker == 'v' and text[0].isdigit():
                         try: text = text.split( None, 1 )[1]
                         except IndexError: text = ''
-                    #vPrint( 'Quiet', debuggingThisModule, "   2", marker, text )
+                    #dPrint( 'Quiet', debuggingThisModule, "   2", marker, text )
                     countWords( text )
                     #if not lineDuples: # Just for detection of start of real USFM
                         #lineDuples.append( (marker, text) )
@@ -304,7 +300,7 @@ def countBookWords( BBB, internalBible, filename, isCurrentBook, internalMarkers
             vPrint( 'Quiet', debuggingThisModule, "Unicode error:", sys.exc_info()[0], err )
             logging.critical( "countBookWords: Invalid line in {} -- line ignored at #{}".format( USFMFilepath, lineCount) )
             if lineCount > 1: vPrint( 'Quiet', debuggingThisModule, 'Previous line was: ', lastLine )
-            #vPrint( 'Quiet', debuggingThisModule, line )
+            #dPrint( 'Quiet', debuggingThisModule, line )
             #raise
 
     return wordCounts
@@ -333,11 +329,11 @@ def loadBibleBookAutocompleteWords( editWindowObject ):
     logging.info( "loadBibleBookAutocompleteWords()" )
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
         vPrint( 'Quiet', debuggingThisModule, "loadBibleBookAutocompleteWords()" )
-        editWindowObject.parentApp.setDebugText( "loadBibleBookAutocompleteWords…" )
+        BiblelatorGlobals.theApp.setDebugText( "loadBibleBookAutocompleteWords…" )
 
-    editWindowObject.parentApp.setWaitStatus( _("Loading {} Bible book words…").format( editWindowObject.projectName ) )
+    BiblelatorGlobals.theApp.setWaitStatus( _("Loading {} Bible book words…").format( editWindowObject.projectName ) )
     currentBBB = editWindowObject.currentVerseKey.getBBB()
-    #vPrint( 'Quiet', debuggingThisModule, "  got BBB", repr(BBB) )
+    #dPrint( 'Quiet', debuggingThisModule, "  got BBB", repr(BBB) )
     if currentBBB == 'UNK': return # UNKnown book -- no use here
 
     if not editWindowObject.internalBible.preloadDone: editWindowObject.internalBible.preload()
@@ -346,7 +342,7 @@ def loadBibleBookAutocompleteWords( editWindowObject ):
         if BBB2 == currentBBB: foundFilename = filename; break
 
     wordCountResults = countBookWords( currentBBB, editWindowObject.internalBible, foundFilename, False )
-    #vPrint( 'Quiet', debuggingThisModule, 'wordCountResults', len(wordCountResults) )
+    #dPrint( 'Quiet', debuggingThisModule, 'wordCountResults', len(wordCountResults) )
 
     # Would be nice to load current book first, but we don't know it yet
     autocompleteWords = []
@@ -354,10 +350,10 @@ def loadBibleBookAutocompleteWords( editWindowObject ):
         #autocompleteWords = [ 'Lord God', 'Lord your(pl) God', '(is)', '(are)', '(were)', '(one who)', ]
     try:
         # Sort the word-list for the book to put the most common words first
-        #vPrint( 'Quiet', debuggingThisModule, 'wordCountResults', currentBBB, discoveryResults )
-        #vPrint( 'Quiet', debuggingThisModule, currentBBB, 'mTWC', discoveryResults['mainTextWordCounts'] )
+        #dPrint( 'Quiet', debuggingThisModule, 'wordCountResults', currentBBB, discoveryResults )
+        #dPrint( 'Quiet', debuggingThisModule, currentBBB, 'mTWC', discoveryResults['mainTextWordCounts'] )
         #qqq = sorted( discoveryResults['mainTextWordCounts'].items(), key=lambda c: -c[1] )
-        #vPrint( 'Quiet', debuggingThisModule, 'qqq', qqq )
+        #dPrint( 'Quiet', debuggingThisModule, 'qqq', qqq )
         for word,count in sorted( wordCountResults.items(),
                                 key=lambda duple: -duple[1] ):
             if len(word) >= editWindowObject.autocompleteMinLength \
@@ -368,7 +364,7 @@ def loadBibleBookAutocompleteWords( editWindowObject ):
     except KeyError:
         vPrint( 'Quiet', debuggingThisModule, "Why did {} have no words???".format( currentBBB ) )
         #pass # Nothing for this book
-    #vPrint( 'Quiet', debuggingThisModule, 'autocompleteWords', len(autocompleteWords) )
+    #dPrint( 'Quiet', debuggingThisModule, 'autocompleteWords', len(autocompleteWords) )
     setAutocompleteWords( editWindowObject, autocompleteWords )
     editWindowObject.addAllNewWords = True
 # end of AutocompleteFunctions.loadBibleBookAutocompleteWords
@@ -389,7 +385,7 @@ def loadBibleAutocompleteWords( editWindowObject ):
     startTime = time.time()
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
         vPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.loadBibleAutocompleteWords()" )
-        editWindowObject.parentApp.setDebugText( "loadBibleAutocompleteWords…" )
+        BiblelatorGlobals.theApp.setDebugText( "loadBibleAutocompleteWords…" )
 
     global internalMarkers
     if internalMarkers is None: # Get our list of markers -- note that the more common note markers are first
@@ -397,9 +393,9 @@ def loadBibleAutocompleteWords( editWindowObject ):
             + BibleOrgSysGlobals.loadedUSFMMarkers.getCharacterMarkersList( includeBackslash=False, includeEndMarkers=False, includeNestedMarkers=True, expandNumberableMarkers=True )
         internalMarkers = ['\\'+marker for marker in internalMarkers]
 
-    editWindowObject.parentApp.setWaitStatus( _("Loading {} Bible words…").format( editWindowObject.projectName ) )
+    BiblelatorGlobals.theApp.setWaitStatus( _("Loading {} Bible words…").format( editWindowObject.projectName ) )
     currentBBB = editWindowObject.currentVerseKey.getBBB()
-    if BibleOrgSysGlobals.debugFlag and debuggingThisModule: vPrint( 'Quiet', debuggingThisModule, "  got current BBB", repr(currentBBB) )
+    vPrint( 'Never', debuggingThisModule, "  got current BBB", repr(currentBBB) )
 
     if not editWindowObject.internalBible.preloadDone: editWindowObject.internalBible.preload()
     bookWordCounts = {}
@@ -413,14 +409,14 @@ def loadBibleAutocompleteWords( editWindowObject ):
                 results = pool.map( countBookWordsHelper, parameters ) # have the pool do our loads
                 assert len(results) == len(editWindowObject.internalBible.maximumPossibleFilenameTuples)
                 for (BBB,filename),counts in zip( editWindowObject.internalBible.maximumPossibleFilenameTuples, results ):
-                    #vPrint( 'Quiet', debuggingThisModule, "XX", BBB, filename, len(counts) if counts else counts )
+                    #dPrint( 'Quiet', debuggingThisModule, "XX", BBB, filename, len(counts) if counts else counts )
                     bookWordCounts[BBB] = counts
                 BibleOrgSysGlobals.alreadyMultiprocessing = False
         else: # Just single threaded
             # Load the books one by one -- assuming that they have regular Paratext style filenames
             for BBB,filename in editWindowObject.internalBible.maximumPossibleFilenameTuples:
                 #if BibleOrgSysGlobals.verbosityLevel>1 or BibleOrgSysGlobals.debugFlag:
-                    #vPrint( 'Quiet', debuggingThisModule, _("  USFMBible: Loading {} from {} from {}…").format( BBB, editWindowObject.internalBible.getAName(), editWindowObject.internalBible.sourceFolder ) )
+                    #dPrint( 'Quiet', debuggingThisModule, _("  USFMBible: Loading {} from {} from {}…").format( BBB, editWindowObject.internalBible.getAName(), editWindowObject.internalBible.sourceFolder ) )
                 bookWordCounts[BBB] = countBookWords( BBB, editWindowObject.internalBible, filename, BBB==currentBBB ) # also saves it
     else:
         logging.critical( "Autocomplete: " + _("No books to load in folder '{}'!").format( editWindowObject.internalBible.sourceFolder ) )
@@ -428,14 +424,14 @@ def loadBibleAutocompleteWords( editWindowObject ):
     # Now combine the books
     autocompleteCounts = {}
     for BBB,counts in bookWordCounts.items(): # combine word counts for all books
-        #vPrint( 'Quiet', debuggingThisModule, "here", BBB, len(counts) )
+        #dPrint( 'Quiet', debuggingThisModule, "here", BBB, len(counts) )
         if counts:
             for word, count in counts.items():
-                #vPrint( 'Quiet', debuggingThisModule, "  ", word, count )
+                #dPrint( 'Quiet', debuggingThisModule, "  ", word, count )
                 if len(word) >= editWindowObject.autocompleteMinLength:
                     if word in autocompleteCounts: autocompleteCounts[word] += count
                     else: autocompleteCounts[word] = count
-    #vPrint( 'Quiet', debuggingThisModule, "there", len(autocompleteCounts) )
+    #dPrint( 'Quiet', debuggingThisModule, "there", len(autocompleteCounts) )
 
     # Now make our list sorted with most common words first
     autocompleteWords = []
@@ -445,11 +441,11 @@ def loadBibleAutocompleteWords( editWindowObject ):
         if ' ' not in word or count > 9:
             autocompleteWords.append( word )
         #else:
-            #vPrint( 'Quiet', debuggingThisModule, 'loadBibleAutocompleteWords discarding', repr(word) )
+            #dPrint( 'Quiet', debuggingThisModule, 'loadBibleAutocompleteWords discarding', repr(word) )
             #if ' ' not in word: halt
-    #if BibleOrgSysGlobals.debugFlag and debuggingThisModule: vPrint( 'Quiet', debuggingThisModule, 'acW', autocompleteWords )
+    #dPrint( 'Never', debuggingThisModule, 'acW', autocompleteWords )
 
-    #vPrint( 'Quiet', debuggingThisModule, 'autocompleteWords', len(autocompleteWords) )
+    #dPrint( 'Quiet', debuggingThisModule, 'autocompleteWords', len(autocompleteWords) )
     setAutocompleteWords( editWindowObject, autocompleteWords )
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
         vPrint( 'Quiet', debuggingThisModule, "loadBibleAutocompleteWords took", time.time()-startTime )
@@ -471,9 +467,9 @@ def loadHunspellAutocompleteWords( editWindowObject, dictionaryFilepath, encodin
     logging.info( "loadHunspellAutocompleteWords( {}, {} )".format( dictionaryFilepath, encoding ) )
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
         vPrint( 'Quiet', debuggingThisModule, "loadHunspellAutocompleteWords( {}, {} )".format( dictionaryFilepath, encoding ) )
-        editWindowObject.parentApp.setDebugText( "loadHunspellAutocompleteWords…" )
+        BiblelatorGlobals.theApp.setDebugText( "loadHunspellAutocompleteWords…" )
 
-    editWindowObject.parentApp.setWaitStatus( _("Loading dictionary…") )
+    BiblelatorGlobals.theApp.setWaitStatus( _("Loading dictionary…") )
     internalCount = None
     autocompleteWords = []
     lineCount = 0
@@ -485,7 +481,7 @@ def loadHunspellAutocompleteWords( editWindowObject, dictionaryFilepath, encodin
                 line = line[1:] # Remove the Unicode Byte Order Marker (BOM)
             if line and line[-1]=='\n': line=line[:-1] # Remove trailing newline character
             if not line: continue # Just discard blank lines
-            #vPrint( 'Quiet', debuggingThisModule, "line", lineCount, repr(line) )
+            #dPrint( 'Quiet', debuggingThisModule, "line", lineCount, repr(line) )
 
             if lineCount==1 and line.isdigit(): # first line seems to be a count
                 internalCount = int( line )
@@ -494,7 +490,7 @@ def loadHunspellAutocompleteWords( editWindowObject, dictionaryFilepath, encodin
             try: word, codes = line.split( '/', 1 )
             except ValueError: word, codes = line, ''
             if word in ('3GPP','AA','ACAS',): continue # Throw out rubbish
-            #vPrint( 'Quiet', debuggingThisModule, "word", repr(word), repr(codes) )
+            #dPrint( 'Quiet', debuggingThisModule, "word", repr(word), repr(codes) )
             autocompleteWords.append( word )
 
             wordDeleteA = word[:-1] if word[-1]=='a' else word
@@ -545,7 +541,7 @@ def loadHunspellAutocompleteWords( editWindowObject, dictionaryFilepath, encodin
             7 -able, last syllable NOT stressed, -ate words <= 2 syllables
             """
             for code in codes:
-                #vPrint( 'Quiet', debuggingThisModule, "  code", code, "for", repr(word) )
+                #dPrint( 'Quiet', debuggingThisModule, "  code", code, "for", repr(word) )
                 if code == 'A': generatedWords.append( 're' + word )
                 elif code == 'a': generatedWords.append( 'mis' + word )
                 elif code == 'B': generatedWords.append( word+'able' ); generatedWords.append( word+'ability' )
@@ -642,7 +638,7 @@ def loadHunspellAutocompleteWords( editWindowObject, dictionaryFilepath, encodin
 
             #lastLine = line
             #if lineCount > 60: break
-    #vPrint( 'Quiet', debuggingThisModule, 'acW', len(autocompleteWords), autocompleteWords )
+    #dPrint( 'Quiet', debuggingThisModule, 'acW', len(autocompleteWords), autocompleteWords )
 
     if editWindowObject.autocompleteMinLength < 4:
         vPrint( 'Quiet', debuggingThisModule, "NOTE: Lengthened autocompleteMinLength from {} to {}".format( editWindowObject.autocompleteMinLength, 4 ) )
@@ -666,9 +662,9 @@ def loadILEXAutocompleteWords( editWindowObject, dictionaryFilepath, lgCodes=Non
     logging.info( "loadILEXAutocompleteWords( {}, {} )".format( dictionaryFilepath, lgCodes ) )
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
         vPrint( 'Quiet', debuggingThisModule, "loadILEXAutocompleteWords( {}, {} )".format( dictionaryFilepath, lgCodes ) )
-        editWindowObject.parentApp.setDebugText( "loadILEXAutocompleteWords…" )
+        BiblelatorGlobals.theApp.setDebugText( "loadILEXAutocompleteWords…" )
 
-    editWindowObject.parentApp.setWaitStatus( _("Loading dictionary…") )
+    BiblelatorGlobals.theApp.setWaitStatus( _("Loading dictionary…") )
     autocompleteWords = []
     lineCount = 0
     with open( dictionaryFilepath, 'rt', encoding='utf-8' ) as dictionaryFile:
@@ -683,7 +679,7 @@ def loadILEXAutocompleteWords( editWindowObject, dictionaryFilepath, lgCodes=Non
                     line = line[3:] # Remove the UTF-8 Unicode Byte Order Marker (BOM)
             if line and line[-1]=='\n': line=line[:-1] # Remove trailing newline character
             if not line: continue # Just discard blank lines
-            #vPrint( 'Quiet', debuggingThisModule, "line", lineCount, repr(line) )
+            #dPrint( 'Quiet', debuggingThisModule, "line", lineCount, repr(line) )
 
             # wd, lg, ps, and sc are the four compulsory fields in each record
             if line.startswith( '\\wd ' ):
@@ -703,7 +699,7 @@ def loadILEXAutocompleteWords( editWindowObject, dictionaryFilepath, lgCodes=Non
 
             #lastLine = line
             #if lineCount > 600: break
-    #vPrint( 'Quiet', debuggingThisModule, 'acW', len(autocompleteWords), autocompleteWords )
+    #dPrint( 'Quiet', debuggingThisModule, 'acW', len(autocompleteWords), autocompleteWords )
 
     if editWindowObject.autocompleteMinLength < 4:
         vPrint( 'Quiet', debuggingThisModule, "NOTE: Lengthened autocompleteMinLength from {} to {}".format( editWindowObject.autocompleteMinLength, 4 ) )
@@ -730,10 +726,10 @@ def getCharactersBeforeCursor( self, charCount=1 ):
     Needed for auto-correct functions.
     """
     #if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        #vPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.getCharactersBeforeCursor( {} )".format( charCount ) )
+        #dPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.getCharactersBeforeCursor( {} )".format( charCount ) )
 
     previousText = self.textBox.get( tk.INSERT+'-{}c'.format( charCount ), tk.INSERT )
-    #vPrint( 'Quiet', debuggingThisModule, 'getCharactersBeforeCursor: returning previousText', repr(previousText) )
+    #dPrint( 'Quiet', debuggingThisModule, 'getCharactersBeforeCursor: returning previousText', repr(previousText) )
     return previousText
 # end of AutocompleteFunctions.getCharactersBeforeCursor
 
@@ -746,16 +742,16 @@ def getWordCharactersBeforeCursor( self, maxCount=4 ):
     Needed for auto-complete functions.
     """
     #if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        #vPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.getWordCharactersBeforeCursor( {} )".format( maxCount ) )
+        #dPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.getWordCharactersBeforeCursor( {} )".format( maxCount ) )
 
     previousText = self.textBox.get( tk.INSERT+'-{}c'.format( maxCount ), tk.INSERT )
-    #vPrint( 'Quiet', debuggingThisModule, "previousText", repr(previousText) )
+    #dPrint( 'Quiet', debuggingThisModule, "previousText", repr(previousText) )
     wordText = ''
     for previousChar in reversed( previousText ):
         if previousChar in self.autocompleteWordChars:
             wordText = previousChar + wordText
         else: break
-    #vPrint( 'Quiet', debuggingThisModule, 'getWordCharactersBeforeCursor: returning wordText', repr(wordText) )
+    #dPrint( 'Quiet', debuggingThisModule, 'getWordCharactersBeforeCursor: returning wordText', repr(wordText) )
     return wordText
 # end of AutocompleteFunctions.getWordCharactersBeforeCursor
 
@@ -769,10 +765,10 @@ def getCharactersAndWordBeforeCursor( self, maxCount=4 ):
     Needed for auto-complete functions.
     """
     #if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        #vPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.getCharactersAndWordBeforeCursor( {} )".format( maxCount ) )
+        #dPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.getCharactersAndWordBeforeCursor( {} )".format( maxCount ) )
 
     previousText = self.textBox.get( tk.INSERT+'-{}c'.format( maxCount ), tk.INSERT )
-    #vPrint( 'Quiet', debuggingThisModule, "previousText", repr(previousText) )
+    #dPrint( 'Quiet', debuggingThisModule, "previousText", repr(previousText) )
     delimiterCount = 0
     wordText = ''
     for previousChar in reversed( previousText ):
@@ -780,10 +776,10 @@ def getCharactersAndWordBeforeCursor( self, maxCount=4 ):
             wordText = previousChar + wordText
         elif previousChar in BibleOrgSysGlobals.TRAILING_WORD_END_CHARS+MULTIPLE_SPACE_SUBSTITUTE+TRAILING_SPACE_SUBSTITUTE:
             if delimiterCount > 0: break
-            #vPrint( 'Quiet', debuggingThisModule, "Found delimiter {!r}".format( previousChar ) )
+            #dPrint( 'Quiet', debuggingThisModule, "Found delimiter {!r}".format( previousChar ) )
             wordText = previousChar + wordText
             delimiterCount += 1
-    #vPrint( 'Quiet', debuggingThisModule, 'getCharactersAndWordBeforeCursor: returning wordText', repr(wordText) )
+    #dPrint( 'Quiet', debuggingThisModule, 'getCharactersAndWordBeforeCursor: returning wordText', repr(wordText) )
     return wordText
 # end of AutocompleteFunctions.getCharactersAndWordBeforeCursor
 
@@ -796,20 +792,20 @@ def getWordBeforeSpace( self, maxCount=20 ):
     Needed for auto-complete functions.
     """
     #if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        #vPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.getWordBeforeSpace( {} )".format( maxCount ) )
+        #dPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.getWordBeforeSpace( {} )".format( maxCount ) )
 
     previousText = self.textBox.get( tk.INSERT+'-{}c'.format( maxCount ), tk.INSERT )
-    #vPrint( 'Quiet', debuggingThisModule, "previousText1", repr(previousText) )
+    #dPrint( 'Quiet', debuggingThisModule, "previousText1", repr(previousText) )
     assert previousText and previousText[-1] in BibleOrgSysGlobals.TRAILING_WORD_END_CHARS+MULTIPLE_SPACE_SUBSTITUTE+TRAILING_SPACE_SUBSTITUTE
     previousText = previousText[:-1] # Drop the character that ended the word
-    #vPrint( 'Quiet', debuggingThisModule, "previousText2", repr(previousText) )
+    #dPrint( 'Quiet', debuggingThisModule, "previousText2", repr(previousText) )
     wordText = ''
     if 1 or previousText and previousText[-1].isalpha():
         for previousChar in reversed( previousText ):
             if previousChar in self.autocompleteWordChars:
                 wordText = previousChar + wordText
             else: break
-    #vPrint( 'Quiet', debuggingThisModule, 'getWordBeforeSpace: returning word Text', repr(wordText) )
+    #dPrint( 'Quiet', debuggingThisModule, 'getWordBeforeSpace: returning word Text', repr(wordText) )
     return wordText
 # end of AutocompleteFunctions.getWordBeforeSpace
 
@@ -821,15 +817,15 @@ def acceptAutocompleteSelection( self, includeTrailingSpace=False ):
     Gets the chosen word and inserts the end of it into the text.
     """
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        #vPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.acceptAutocompleteSelection( {} )".format( includeTrailingSpace ) )
+        #dPrint( 'Quiet', debuggingThisModule, "AutocompleteFunctions.acceptAutocompleteSelection( {} )".format( includeTrailingSpace ) )
         assert self.autocompleteBox is not None
 
     currentWord = self.autocompleteBox.get( tk.ACTIVE )
-    #vPrint( 'Quiet', debuggingThisModule, '  autocompleteBox currentWord', currentWord )
+    #dPrint( 'Quiet', debuggingThisModule, '  autocompleteBox currentWord', currentWord )
     self.removeAutocompleteBox()
 
     if self.autocompleteOverlap:
-        #vPrint( 'Quiet', debuggingThisModule, "Have {!r} with overlap {!r}".format( currentWord, self.autocompleteOverlap ) )
+        #dPrint( 'Quiet', debuggingThisModule, "Have {!r} with overlap {!r}".format( currentWord, self.autocompleteOverlap ) )
         assert currentWord.startswith( self.autocompleteOverlap )
         #currentWord = currentWord[len(self.autocompleteOverlap):]
 
@@ -839,7 +835,7 @@ def acceptAutocompleteSelection( self, includeTrailingSpace=False ):
     self.textBox.insert( tk.INSERT, currentWord[len(self.autocompleteOverlap):] \
                                     + (' ' if includeTrailingSpace else '') )
 
-    #vPrint( 'Quiet', debuggingThisModule, "acceptAutocompleteSelection for {!r}".format( currentWord ) )
+    #dPrint( 'Quiet', debuggingThisModule, "acceptAutocompleteSelection for {!r}".format( currentWord ) )
     addNewAutocompleteWord( self, currentWord )
 
     ## Put this word at the beginning of the list so it comes up on top next time
@@ -865,17 +861,17 @@ def addNewAutocompleteWord( self, possibleNewWord ):
         remainder = possibleNewWord
         while ' ' in remainder:
             individualWord, remainder = remainder.split( None, 1 )
-            #vPrint( 'Quiet', debuggingThisModule, "  word={!r}, remainder={!r}".format( individualWord, remainder ) )
-            #vPrint( 'Quiet', debuggingThisModule, "Recursive1 of {!r}".format( individualWord ) )
+            #dPrint( 'Quiet', debuggingThisModule, "  word={!r}, remainder={!r}".format( individualWord, remainder ) )
+            #dPrint( 'Quiet', debuggingThisModule, "Recursive1 of {!r}".format( individualWord ) )
             addNewAutocompleteWord( self, individualWord ) # recursive call
-            #vPrint( 'Quiet', debuggingThisModule, "Recursive2 of {!r}".format( remainder ) )
+            #dPrint( 'Quiet', debuggingThisModule, "Recursive2 of {!r}".format( remainder ) )
             addNewAutocompleteWord( self, remainder ) # recursive call
 
     while possibleNewWord and possibleNewWord[-1] in END_CHARS_TO_REMOVE:
         possibleNewWord = possibleNewWord[:-1] # Remove certain final punctuation
 
     if len( possibleNewWord ) > self.autocompleteMinLength:
-        #vPrint( 'Quiet', debuggingThisModule, "Adding new autocomplete word: {!r}".format( possibleNewWord ) )
+        #dPrint( 'Quiet', debuggingThisModule, "Adding new autocomplete word: {!r}".format( possibleNewWord ) )
         # Put this word at the beginning of the list so it comes up on top next time
         firstLetter, remainder = possibleNewWord[0], possibleNewWord[1:]
         try: self.autocompleteWords[firstLetter].remove( remainder )
@@ -893,7 +889,7 @@ def briefDemo() -> None:
     Demo program to handle command line parameters and then run what they want.
     """
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
-    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
+    vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
 
     tkRootWindow = tk.Tk()
     tkRootWindow.title( programNameVersion )
@@ -901,6 +897,9 @@ def briefDemo() -> None:
 
     #uEW = AutocompleteFunctions( tkRootWindow, None )
 
+    # Program a shutdown
+    tkRootWindow.after( 2_000, tkRootWindow.destroy ) # Destroy the widget after 2 seconds
+
     # Start the program running
     # tkRootWindow.mainloop()
 # end of AutocompleteFunctions.briefDemo
@@ -910,7 +909,7 @@ def fullDemo() -> None:
     Full demo to check class is working
     """
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
-    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
+    vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
 
     tkRootWindow = tk.Tk()
     tkRootWindow.title( programNameVersion )
@@ -918,6 +917,9 @@ def fullDemo() -> None:
 
     #uEW = AutocompleteFunctions( tkRootWindow, None )
 
+    # Program a shutdown
+    tkRootWindow.after( 30_000, tkRootWindow.destroy ) # Destroy the widget after 30 seconds
+
     # Start the program running
     tkRootWindow.mainloop()
 # end of AutocompleteFunctions.fullDemo
