@@ -38,8 +38,15 @@ debuggingThisModule = False
 
 # BibleOrgSys imports
 from BibleOrgSys import BibleOrgSysGlobals
-from BibleOrgSys.BibleOrgSysGlobals import vPrint
+from BibleOrgSys.BibleOrgSysGlobals import fnPrint, vPrint, dPrint
 
+# Biblelator imports
+if __name__ == '__main__':
+    import sys
+    aboveAboveFolderpath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
+    if aboveAboveFolderpath not in sys.path:
+        sys.path.insert( 0, aboveAboveFolderpath )
+from Biblelator import BiblelatorGlobals
 
 
 
@@ -52,7 +59,7 @@ def setAutocorrectEntries( self, autocorrectEntryList, append=False ):
         so that more common/likely words can appear at the top of the list if desired.
     """
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        #vPrint( 'Quiet', debuggingThisModule, "AutocorrectFunctions.setAutocorrectEntries( {} )".format( autocorrectEntryList, append ) )
+        #dPrint( 'Quiet', debuggingThisModule, "AutocorrectFunctions.setAutocorrectEntries( {} )".format( autocorrectEntryList, append ) )
         vPrint( 'Quiet', debuggingThisModule, "AutocorrectFunctions.setAutocorrectEntries( {}.., {} )".format( len(autocorrectEntryList), append ) )
 
     if append: self.autocorrectEntries.extend( autocorrectEntryList )
@@ -101,7 +108,7 @@ def setDefaultAutocorrectEntries( self ):
 
     from datetime import datetime # Sorry -- this is a hack for our project
     ourAutocorrectEntries.append( ('QQQ',' [{} {}] XXX' \
-                .format( self.parentApp.currentUserInitials, datetime.now().strftime( '%d%b%y' ) ) ) )
+                .format( BiblelatorGlobals.theApp.currentUserInitials, datetime.now().strftime( '%d%b%y' ) ) ) )
 
     # Add trailing spaces on these ones so that autocomplete doesn't kick in as well
     #ourAutocorrectEntries.append( ('(in','(incl) ') )
@@ -120,7 +127,7 @@ def briefDemo() -> None:
     import tkinter as tk
 
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
-    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
+    vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
 
     tkRootWindow = tk.Tk()
     tkRootWindow.title( programNameVersion )
