@@ -41,7 +41,7 @@ import re
 
 # BibleOrgSys imports
 from BibleOrgSys import BibleOrgSysGlobals
-from BibleOrgSys.BibleOrgSysGlobals import vPrint
+from BibleOrgSys.BibleOrgSysGlobals import fnPrint, vPrint, dPrint
 from BibleOrgSys.Bible import Bible
 from BibleOrgSys.Reference.VerseReferences import SimpleVerseKey, BBB_RE #, FlexibleVersesKey
 from BibleOrgSys.Reference.BibleReferencesLinks import BibleReferencesLinks
@@ -53,10 +53,10 @@ if __name__ == '__main__':
     aboveAboveFolderpath = os.path.dirname( os.path.dirname( os.path.dirname( os.path.abspath( __file__ ) ) ) )
     if aboveAboveFolderpath not in sys.path:
         sys.path.insert( 0, aboveAboveFolderpath )
-from Biblelator.BiblelatorGlobals import APP_NAME_VERSION, BIBLE_GROUP_CODES
+from Biblelator import BiblelatorGlobals
 
 
-LAST_MODIFIED_DATE = '2020-04-26' # by RJH
+LAST_MODIFIED_DATE = '2020-05-10' # by RJH
 SHORT_PROGRAM_NAME = "BiblelatorHelpers"
 PROGRAM_NAME = "Biblelator helpers"
 PROGRAM_VERSION = '0.46'
@@ -76,7 +76,7 @@ def createEmptyUSFMBookText( BBB, getNumChapters, getNumVerses ):
 
     USFMAbbreviation = BibleOrgSysGlobals.loadedBibleBooksCodes.getUSFMAbbreviation( BBB )
     USFMNumber = BibleOrgSysGlobals.loadedBibleBooksCodes.getUSFMNumber( BBB )
-    bookText = '\\id {} Empty book created by {}\n'.format( USFMAbbreviation.upper(), APP_NAME_VERSION )
+    bookText = '\\id {} Empty book created by {}\n'.format( USFMAbbreviation.upper(), BiblelatorGlobals.APP_NAME_VERSION )
     bookText += '\\ide UTF-8\n'
     bookText += '\\h Bookname\n'
     bookText += '\\mt Book Title\n'
@@ -101,9 +101,9 @@ def createEmptyUSFMBooks( folderpath, currentBBB, requestDict ):
             Versification: 'KJV'
             Version: 'KJV1611'
     """
-    from BibleVersificationSystems import BibleVersificationSystem
-    from InternalBible import OT39_BOOKLIST, NT27_BOOKLIST
-    from InternalBibleInternals import BOS_ALL_ADDED_MARKERS
+    from BibleOrgSys.Reference.BibleVersificationSystems import BibleVersificationSystem
+    from BibleOrgSys.Internals.InternalBible import OT39_BOOKLIST, NT27_BOOKLIST
+    from BibleOrgSys.Internals.InternalBibleInternals import BOS_ALL_ADDED_MARKERS
     from BibleOrgSys.Formats.USFMBible import USFMBible
 
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
@@ -123,7 +123,7 @@ def createEmptyUSFMBooks( folderpath, currentBBB, requestDict ):
         uB.preload()
         vPrint( 'Quiet', debuggingThisModule, "Fill Bible2", uB )
         #uB.loadBooks()
-        #vPrint( 'Quiet', debuggingThisModule, "Fill Bible3", uB )
+        #dPrint( 'Quiet', debuggingThisModule, "Fill Bible3", uB )
 
     if requestDict['Books'] == 'None': booklist = []
     elif requestDict['Books'] == 'Current': booklist = [ currentBBB ]
@@ -151,7 +151,7 @@ def createEmptyUSFMBooks( folderpath, currentBBB, requestDict ):
 
         if requestDict['Fill'] == 'None': bookText = ''
         elif requestDict['Fill'] == 'Basic':
-            bookText = '\\id {} Empty book created by {}\n'.format( USFMAbbreviation.upper(), APP_NAME_VERSION )
+            bookText = '\\id {} Empty book created by {}\n'.format( USFMAbbreviation.upper(), BiblelatorGlobals.APP_NAME_VERSION )
             bookText += '\\ide UTF-8\n'
             bookText += '\\h Bookname\n'
             bookText += '\\mt Book Title\n'
@@ -167,13 +167,13 @@ def createEmptyUSFMBooks( folderpath, currentBBB, requestDict ):
             bookText = ''
             for verseDataEntry in uBB._processedLines:
                 pseudoMarker, cleanText = verseDataEntry.getMarker(), verseDataEntry.getCleanText()
-                #vPrint( 'Quiet', debuggingThisModule, BBB, pseudoMarker, repr(cleanText) )
+                #dPrint( 'Quiet', debuggingThisModule, BBB, pseudoMarker, repr(cleanText) )
                 if '¬' in pseudoMarker or pseudoMarker in BOS_ALL_ADDED_MARKERS or pseudoMarker in ('c#','vp#',):
                     continue # Just ignore added markers -- not needed here
                 #if pseudoMarker in ('v','f','fr','x','xo',): # These fields should always end with a space but the processing will have removed them
                     #pseudoMarker += ' ' # Append a space since it didn't have one
                 #if pseudoMarker in ALL_CHAR_MARKERS: # Character markers to be closed
-                    #vPrint( 'Quiet', debuggingThisModule, "CHAR MARKER" )
+                    #dPrint( 'Quiet', debuggingThisModule, "CHAR MARKER" )
                     #pass
                     ##if (USFM[-2]=='\\' or USFM[-3]=='\\') and USFM[-1]!=' ':
                     #if bookText[-1] != ' ':
@@ -187,7 +187,7 @@ def createEmptyUSFMBooks( folderpath, currentBBB, requestDict ):
                 elif pseudoMarker == 'c': bookText += '\\c {}'.format( cleanText )
                 elif pseudoMarker == 'v': bookText += '\\v {} '.format( cleanText )
                 else: bookText += '\\{} '.format( pseudoMarker )
-                #vPrint( 'Quiet', debuggingThisModule, pseudoMarker, USFM[-200:] )
+                #dPrint( 'Quiet', debuggingThisModule, pseudoMarker, USFM[-200:] )
         else: halt # programming error
 
         # Write the actual file
@@ -235,8 +235,7 @@ def mapReferenceVerseKey( mainVerseKey ):
         }
 
     if mainVerseKey in REFERENCE_VERSE_KEY_DICT:
-        if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            vPrint( 'Quiet', debuggingThisModule, '  returning {}'.format( REFERENCE_VERSE_KEY_DICT[mainVerseKey].getShortText() ) )
+        vPrint( 'Never', debuggingThisModule, '  returning {}'.format( REFERENCE_VERSE_KEY_DICT[mainVerseKey].getShortText() ) )
         return REFERENCE_VERSE_KEY_DICT[mainVerseKey]
 # end of BiblelatorHelpers.mapReferenceVerseKey
 
@@ -249,13 +248,12 @@ def mapParallelVerseKey( forGroupCode, mainVerseKey ):
     """
     if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
         vPrint( 'Quiet', debuggingThisModule, "mapParallelVerseKey( {}, {} )".format( forGroupCode, mainVerseKey.getShortText() ) )
-    groupIndex = BIBLE_GROUP_CODES.index( forGroupCode ) - 1
+    groupIndex = BiblelatorGlobals.BIBLE_GROUP_CODES.index( forGroupCode ) - 1
     parallelVerseKeyDict = {
         SimpleVerseKey('MAT','3','13'): (SimpleVerseKey('MRK','1','9'), SimpleVerseKey('LUK','3','21'), SimpleVerseKey('JHN','1','31') )
         }
     if mainVerseKey in parallelVerseKeyDict:
-        if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            vPrint( 'Quiet', debuggingThisModule, '  returning {}'.format( parallelVerseKeyDict[mainVerseKey][groupIndex].getShortText() ) )
+        vPrint( 'Never', debuggingThisModule, '  returning {}'.format( parallelVerseKeyDict[mainVerseKey][groupIndex].getShortText() ) )
         return parallelVerseKeyDict[mainVerseKey][groupIndex]
 # end of BiblelatorHelpers.mapParallelVerseKey
 
@@ -292,7 +290,7 @@ def mapReferencesVerseKey( mainVerseKey ):
             #}
         #if mainVerseKey in REFERENCE_VERSE_KEY_DICT:
             #if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-                #vPrint( 'Quiet', debuggingThisModule, '  returning {}'.format( REFERENCE_VERSE_KEY_DICT[mainVerseKey].getShortText() ) )
+                #dPrint( 'Quiet', debuggingThisModule, '  returning {}'.format( REFERENCE_VERSE_KEY_DICT[mainVerseKey].getShortText() ) )
             #return REFERENCE_VERSE_KEY_DICT[mainVerseKey]
 # end of BiblelatorHelpers.mapReferencesVerseKey
 
@@ -318,23 +316,22 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
         Given some verse data (a string or an InternalBibleEntryList
             returns True or False whether a section heading is found in it
         """
-        if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-            vPrint( 'Quiet', debuggingThisModule, "sectionFoundIn( {!r} )".format( verseData ) )
+        vPrint( 'Never', debuggingThisModule, "sectionFoundIn( {!r} )".format( verseData ) )
 
         if verseData is None: return False
 
         elif isinstance( verseData, str ):
-            #vPrint( 'Quiet', debuggingThisModule, "  It's a string!" )
+            #dPrint( 'Quiet', debuggingThisModule, "  It's a string!" )
             if '\\s ' in thisVerseData or '\\s1' in thisVerseData \
             or '\\s2' in thisVerseData or '\\s3' in thisVerseData:
                 return True
 
         elif isinstance( verseData, tuple ):
-            #vPrint( 'Quiet', debuggingThisModule, "  It's an InternalBibleEntryList!" )
+            #dPrint( 'Quiet', debuggingThisModule, "  It's an InternalBibleEntryList!" )
             assert len(verseData) == 2
             verseDataList, context = verseData
-            #vPrint( 'Quiet', debuggingThisModule, '   dataList', repr(verseDataList) )
-            #vPrint( 'Quiet', debuggingThisModule, '    context', repr(context) )
+            #dPrint( 'Quiet', debuggingThisModule, '   dataList', repr(verseDataList) )
+            #dPrint( 'Quiet', debuggingThisModule, '    context', repr(context) )
             for verseDataEntry in verseDataList:
                 if isinstance( verseDataEntry, InternalBibleEntry ):
                     marker, cleanText = verseDataEntry.getMarker(), verseDataEntry.getCleanText()
@@ -365,12 +362,12 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
     # Start of main section of findCurrentSection
     BBB, C, V = currentVerseKey.getBCV()
     intC, intV = currentVerseKey.getChapterNumberInt(), currentVerseKey.getVerseNumberInt()
-    #vPrint( 'Quiet', debuggingThisModule, 'fCS at', BBB, C, intC, V, intV )
+    #dPrint( 'Quiet', debuggingThisModule, 'fCS at', BBB, C, intC, V, intV )
 
     # First let's find the beginning of the section
     #  which could be in the current verse/chapter,
     #   or in the previous chapter (at most we assume)
-    #vPrint( 'Quiet', debuggingThisModule, 'fCS finding start…' )
+    #dPrint( 'Quiet', debuggingThisModule, 'fCS finding start…' )
     firstC = max( intC-1, 0 )
     found = False
     for thisC in reversed( range( firstC, intC+1 ) ): # Look backwards
@@ -389,7 +386,7 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
 
     # Now let's find the end of the section
     #  which could be in the current chapter, or in the next chapter (at most we assume)
-    #vPrint( 'Quiet', debuggingThisModule, 'fCS finding end…' )
+    #dPrint( 'Quiet', debuggingThisModule, 'fCS finding end…' )
     lastC = min( intC+1, getNumChapters( BBB ) )
     found = False
     for thisC in range( intC, lastC+1 ):
@@ -405,13 +402,13 @@ def findCurrentSection( currentVerseKey, getNumChapters, getNumVerses, getVerseD
         if found: break
     if not found: found = lastC, numVerses
     endKey = SimpleVerseKey( BBB, found[0], found[1] )
-    #vPrint( 'Quiet', debuggingThisModule, "fCS returning", startKey.getShortText(), endKey.getShortText() )
+    #dPrint( 'Quiet', debuggingThisModule, "fCS returning", startKey.getShortText(), endKey.getShortText() )
     return startKey, endKey
 # end of BiblelatorHelpers.findCurrentSection
 
 
 
-def handleInternalBibles( self, internalBible, controllingWindow ):
+def handleInternalBibles( internalBible:Bible, controllingWindow ) -> Bible:
     """
     Try to only have one copy of internal Bibles
         even if it's open in multiple windows.
@@ -419,16 +416,14 @@ def handleInternalBibles( self, internalBible, controllingWindow ):
     Note that Biblelator never directly changes InternalBible objects --
         they are effectively 'read-only'.
 
-    "self" here is the main Application object.
-
     Returns an internal Bible object.
     """
     debuggingThisFunction = False
     if debuggingThisFunction or (BibleOrgSysGlobals.debugFlag and debuggingThisModule):
         vPrint( 'Quiet', debuggingThisModule, "handleInternalBibles( {}, {} )".format( internalBible, controllingWindow ) )
         assert isinstance( internalBible, Bible )
-        #self.setDebugText( "handleInternalBibles" )
-        #vPrint( 'Quiet', debuggingThisModule, "hereHIB0", repr(internalBible), len(self.internalBibles) )
+        #BiblelatorGlobals.theApp.setDebugText( "handleInternalBibles" )
+        #dPrint( 'Quiet', debuggingThisModule, "hereHIB0", repr(internalBible), len(BiblelatorGlobals.theApp.internalBibles) )
 
     result = internalBible # Default to returning what we were given
     if debuggingThisFunction and internalBible is None:
@@ -436,7 +431,7 @@ def handleInternalBibles( self, internalBible, controllingWindow ):
     if internalBible is not None:
         if debuggingThisFunction: vPrint( 'Quiet', debuggingThisModule, "  hIB: Not None" )
         foundControllingWindowList = None
-        for iB,cWs in self.internalBibles:
+        for iB,cWs in BiblelatorGlobals.theApp.internalBibles:
             # Some of these variables will be None but they'll still match
             #and internalBible.sourceFilepath == iB.sourceFilepath \ # PTX Bible sets sourceFilepath but others don't!
             if type(internalBible) is type(iB) \
@@ -455,15 +450,15 @@ def handleInternalBibles( self, internalBible, controllingWindow ):
                     result, foundControllingWindowList = iB, cWs
                     break
 
-        if foundControllingWindowList is None: self.internalBibles.append( (internalBible,[controllingWindow]) )
+        if foundControllingWindowList is None: BiblelatorGlobals.theApp.internalBibles.append( (internalBible,[controllingWindow]) )
         else: foundControllingWindowList.append( controllingWindow )
 
     if debuggingThisFunction or debuggingThisModule or (BibleOrgSysGlobals.debugFlag and debuggingThisModule):
-        vPrint( 'Quiet', debuggingThisModule, "Internal Bibles ({}) now:".format( len(self.internalBibles) ) )
-        for something in self.internalBibles:
+        vPrint( 'Quiet', debuggingThisModule, "Internal Bibles ({}) now:".format( len(BiblelatorGlobals.theApp.internalBibles) ) )
+        for something in BiblelatorGlobals.theApp.internalBibles:
             vPrint( 'Quiet', debuggingThisModule, "  ", something )
-        vPrint( 'Quiet', debuggingThisModule, self.internalBibles )
-        for j,(iB,cWs) in enumerate( self.internalBibles ):
+        vPrint( 'Quiet', debuggingThisModule, BiblelatorGlobals.theApp.internalBibles )
+        for j,(iB,cWs) in enumerate( BiblelatorGlobals.theApp.internalBibles ):
             vPrint( 'Quiet', debuggingThisModule, "  {}/ {} in {}".format( j+1, iB.getAName(), cWs ) )
             vPrint( 'Quiet', debuggingThisModule, "      {!r} {!r} {!r} {!r}".format( iB.name, iB.givenName, iB.shortName, iB.abbreviation ) )
             vPrint( 'Quiet', debuggingThisModule, "      {!r} {!r} {!r} {!r}".format( iB.sourceFolder, iB.sourceFilename, iB.sourceFilepath, iB.fileExtension ) )
@@ -488,7 +483,7 @@ def logChangedFile( userName, loggingFolder, projectName, savedBBB, bookText ):
     Just logs some info about the recently changed book to a log file for the project.
     """
     #if BibleOrgSysGlobals.debugFlag and debuggingThisModule:
-        #vPrint( 'Quiet', debuggingThisModule, "logChangedFile( {}, {!r}, {}, {} )".format( loggingFolder, projectName, savedBBB, len(bookText) ) )
+        #dPrint( 'Quiet', debuggingThisModule, "logChangedFile( {}, {!r}, {}, {} )".format( loggingFolder, projectName, savedBBB, len(bookText) ) )
 
     filepath = getChangeLogFilepath( loggingFolder, projectName )
 
@@ -523,7 +518,7 @@ def parseEnteredBooknameField( bookNameEntry, currentBBB, CEntry, VEntry, BBBfun
 
     # Do a bit of preliminary cleaning-up
     bookNameEntry = bookNameEntry.strip().replace( '  ', ' ' )
-    #vPrint( 'Quiet', debuggingThisModule, "parseEnteredBooknameField: pulling apart {!r}".format( bookNameEntry ) )
+    #dPrint( 'Quiet', debuggingThisModule, "parseEnteredBooknameField: pulling apart {!r}".format( bookNameEntry ) )
 
     # Without the bookname (i.e., stay in current book)
     # Do these first because they are more strict (only digits and use re.fullmatch not re.search or re.match)
@@ -608,17 +603,17 @@ def briefDemo() -> None:
     from tkinter import Tk
 
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
-    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
+    vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
 
     tkRootWindow = Tk()
     tkRootWindow.title( programNameVersion )
 
     #swnd = SaveWindowsLayoutNameDialog( tkRootWindow, ["aaa","BBB","CcC"], "Test SWND" )
-    #vPrint( 'Quiet', debuggingThisModule, "swndResult", swnd.result )
+    #dPrint( 'Quiet', debuggingThisModule, "swndResult", swnd.result )
     #dwnd = DeleteWindowsLayoutNameDialog( tkRootWindow, ["aaa","BBB","CcC"], "Test DWND" )
-    #vPrint( 'Quiet', debuggingThisModule, "dwndResult", dwnd.result )
+    #dPrint( 'Quiet', debuggingThisModule, "dwndResult", dwnd.result )
     #srb = SelectResourceBox( tkRootWindow, [(x,y) for x,y, in {"ESV":"ENGESV","WEB":"ENGWEB","MS":"MBTWBT"}.items()], "Test SRB" )
-    #vPrint( 'Quiet', debuggingThisModule, "srbResult", srb.result )
+    #dPrint( 'Quiet', debuggingThisModule, "srbResult", srb.result )
 
     # Program a shutdown
     tkRootWindow.after( 2_000, tkRootWindow.destroy ) # Destroy the widget after 2 seconds
@@ -634,17 +629,17 @@ def fullDemo() -> None:
     from tkinter import Tk
 
     BibleOrgSysGlobals.introduceProgram( __name__, programNameVersion, LAST_MODIFIED_DATE )
-    if BibleOrgSysGlobals.debugFlag: vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
+    vPrint( 'Quiet', debuggingThisModule, "Running demo…" )
 
     tkRootWindow = Tk()
     tkRootWindow.title( programNameVersion )
 
     #swnd = SaveWindowsLayoutNameDialog( tkRootWindow, ["aaa","BBB","CcC"], "Test SWND" )
-    #vPrint( 'Quiet', debuggingThisModule, "swndResult", swnd.result )
+    #dPrint( 'Quiet', debuggingThisModule, "swndResult", swnd.result )
     #dwnd = DeleteWindowsLayoutNameDialog( tkRootWindow, ["aaa","BBB","CcC"], "Test DWND" )
-    #vPrint( 'Quiet', debuggingThisModule, "dwndResult", dwnd.result )
+    #dPrint( 'Quiet', debuggingThisModule, "dwndResult", dwnd.result )
     #srb = SelectResourceBox( tkRootWindow, [(x,y) for x,y, in {"ESV":"ENGESV","WEB":"ENGWEB","MS":"MBTWBT"}.items()], "Test SRB" )
-    #vPrint( 'Quiet', debuggingThisModule, "srbResult", srb.result )
+    #dPrint( 'Quiet', debuggingThisModule, "srbResult", srb.result )
 
     # Program a shutdown
     tkRootWindow.after( 30_000, tkRootWindow.destroy ) # Destroy the widget after 30 seconds
